# major.minor.patch (e.g. 1.2.3) only.
#%global major %{version}
%define majver 0
%define minorver 2
%define patchver 0
%global major	0.2

%define libname %mklibname camera %major
%define devname %mklibname -d camera

Name:    libcamera
Version: 0.2.0
Release: %mkrel 4
Summary: A library to support complex camera ISPs
Group:   System/Libraries
License: LGPLv2+ and GPLv2
URL:     https://libcamera.org/
Source0: %{name}-%{version}.tar.xz
Source1: qcam.desktop

BuildRequires: doxygen
BuildRequires: gcc-c++
BuildRequires: gtest-devel
BuildRequires: desktop-file-utils
BuildRequires: meson
BuildRequires: openssl
BuildRequires: ninja
BuildRequires: pybind11-devel
BuildRequires: python3-jinja2
BuildRequires: python3-ply
BuildRequires: python3-yaml
BuildRequires: boost-devel
BuildRequires: pkgconfig(glib-2.0)
BuildRequires: gnutls-devel
BuildRequires: libatomic
BuildRequires: libevent-devel
BuildRequires: libtiff-devel
BuildRequires: libyaml-devel
BuildRequires: lttng-ust-devel
BuildRequires: pkgconfig(Qt5Core)
BuildRequires: pkgconfig(Qt5Gui)
BuildRequires: pkgconfig(Qt5Widgets)
BuildRequires: pkgconfig(gstreamer-video-1.0)
BuildRequires: pkgconfig(gstreamer-allocators-1.0)

%description
libcamera is a library that deals with heavy hardware image processing
operations of complex camera devices that are shared between the linux
host all while allowing offload of certain aspects to the control of
complex camera hardware such as ISPs.

Hardware support includes USB UVC cameras, libv4l cameras as well as more
complex ISPs (Image Signal Processor).

%package     -n %libname
Group:   System/Libraries
Summary:     Library package for %{name}
Obsoletes: lib64camera0.2.0
Provides: lib64camera0.2.0 = %{version}-%{release}

%description -n %libname
Library for %{name}.

%package     -n %devname
Summary:     Development package for %{name}
Group:   Development/Libraries
Requires:    %{libname} = %{version}-%{release}
Provides:    %{name}-devel = %{version}-%{release}

%description -n %devname
Files for development with %{name}.

%package     doc
Summary:     Documentation for %{name}
Group:      Documentation

%description doc
HTML based documentation for %{name} including getting started and API.

%package     ipa
Summary:     ISP Image Processing Algorithm Plugins for %{name}
Group:      Video
Requires:    %{libname} = %{version}-%{release}

%description ipa
Image Processing Algorithms plugins for interfacing with device
ISPs for %{name}

%package     tools
Summary:     Tools for %{name}
Group:       Video
Requires:    %{libname} = %{version}-%{release}

%description tools
Command line tools for %{name}

%package     qcam
Summary:     Graphical QCam application for %{name}
Group:       Video
Requires:    %{libname} = %{version}-%{release}

%description qcam
Graphical QCam application for %{name}

%package     -n gstreamer1.0-libcamera
Summary:     GSTreamer plugin for %{name}
Group:       System/Libraries
Requires:    %{libname} = %{version}-%{release}

%description -n gstreamer1.0-libcamera
GSTreamer plugins for %{name}

%package     v4l2
Summary:     video4linux2-plugin for %{name}
Group:       Video
Requires:    %{libname} = %{version}-%{release}

%description v4l2
v4l2 video4linux2 plugin for %{name}


%prep
%setup -qn %{name}-%{version}
%autopatch -p1

%build
export CFLAGS="%{optflags} -Wno-deprecated-declarations"
export CXXFLAGS="%{optflags} -Wno-deprecated-declarations"
%meson -Dipas=ipu3,rkisp1,rpi/vc4,vimc -Dv4l2="true" -Dpycamera="disabled" -Dtracing="enabled"
%meson_build

%install
%meson_install

# Install Desktop Entry file
desktop-file-install --dir=%{buildroot}%{_datadir}/applications %SOURCE1

# Remove the Sphinx build leftovers
rm -rf %{buildroot}%{_docdir}/%{name}-*/html/.buildinfo
rm -rf %{buildroot}%{_docdir}/%{name}-*/html/.doctrees

%files -n %libname
%{_libdir}/libcamera*.so.%{majver}*

%files -n %devname
%{_includedir}/%{name}/
%{_libdir}/libcamera*.so
%{_libdir}/pkgconfig/libcamera-base.pc
%{_libdir}/pkgconfig/libcamera.pc

%files doc
%doc %{_docdir}/%{name}-*/

%files ipa
%{_datadir}/libcamera/
%{_libdir}/libcamera/
%{_libexecdir}/libcamera/

%files -n gstreamer1.0-libcamera
%{_libdir}/gstreamer-1.0/libgstlibcamera.so

%files qcam
%{_bindir}/qcam
%{_datadir}/applications/qcam.desktop

%files tools
%{_bindir}/cam
%{_bindir}/lc-compliance

%files v4l2
%{_bindir}/libcamerify


%changelog
* Tue Apr 02 2024 tex - 0.2.0-4pclos2024
- fix the library file because it is broke

* Wed Mar 27 2024 onkelho <oh.quait at gmail.com> - 0.2.0-3quait2024
- v4l2: Unset _TIME_BITS in addition to _FILE_OFFSET_BITS
- libcamera fails to build from source in Debian/Ubuntu on 32-bit
- architectures under 64-bit time_t (to avoid the 'year 2038 problem'),
- because its v4l2 module legitimately un-sets
- _FILE_OFFSET_BITS for building but this is not allowed without
- also unsetting _TIME_BITS.
- Having verified that nothing in this module is sensitive to 64-bit
- time_t (none of the functions it intercepts handle time), we also
- unset _TIME_BITS to allow this to build as before.

* Mon Mar 25 2024 onkelho <oh.quait at gmail.com> - 0.2.0-2quait2024
- rebuild
- 3 days	android: camera_device: Save capture settings unconditionallyHEADmaster	Fang Hui
- 5 days	apps: lc-compliance: Re-organize source directory	Jacopo Mondi
- 5 days	apps: lc-compliance: Fix typo in comment	Jacopo Mondi
- 5 days	apps: lc-compliance: Check that requests complete successfully	Nícolas F. R. A. Prado
- 6 days	utils: tuning: readme: Improve names of dependency packages	Paul Elder
- 10 days	checkstyle: Work around bug in difflib	Stefan Klug
- 10 days	libcamera: camera_sensor: Expose the Bayer order	Laurent Pinchart
- 10 days	libcamera: camera_sensor: Test for read-only HBLANK with READ_ONLY flag	Laurent Pinchart
- 10 days	libcamera: camera_sensor: Reorder functions	Laurent Pinchart
- 10 days	libcamera: camera_sensor: Drop updateControlInfo() function	Laurent Pinchart
- 10 days	libcamera: camera_sensor: Move related classes to subdirectory	Laurent Pinchart
- 10 days	libcamera: v4l2_subdevice: Add V4L2Subdevice::Route structure	Laurent Pinchart
- 10 days	libcamera: v4l2_subdevice: Replace Routing::toString() with operator<<()	Laurent Pinchart
- 10 days	libcamera: v4l2_subdevice: Add stream support to get/set functions	Laurent Pinchart
- 10 days	libcamera: v4l2_subdevice: Rename V4L2SubdeviceFormat::mbus_code to code	Laurent Pinchart
- 10 days	libcamera: v4l2_subdevice: Drop V4L2SubdeviceFormat::bitsPerPixel()	Laurent Pinchart
- 10 days	libcamera: v4l2_subdevice: Extend MediaBusFormatInfo with metadata formats	Laurent Pinchart
- 10 days	libcamera: v4l2_subdevice: Expose media bus format info as internal API	Laurent Pinchart
- 10 days	libcamera: v4l2_subdevice: Add code member to MediaBusFormatInfo	Laurent Pinchart
- 10 days	libcamera: v4l2_subdevice: Rename V4L2SubdeviceFormatInfo	Laurent Pinchart
- 13 days	libcamera: controls: Add policy parameter to ControlList::merge()	Stefan Klug
- 13 days	libcamera: framebuffer_allocator: Remove entry if allocation fails	Barnabás Pőcze
- 13 days	libcamera: framebuffer_allocator: Use default destructor	Barnabás Pőcze
- 13 days	libcamera: framebuffer_allocator: Move from argument in constructor	Barnabás Pőcze
- 14 days	cam: capture_script: Make parseRectangles work for non-array	Paul Elder
- 14 days	utils: checkstyle.py: Fix known_trailers sort order	Hans de Goede
- 14 days	utils: checkstyle.py: Add Co-developed-by to known_trailers

* Sun Feb 04 2024 onkelho <oh.quait at gmail.com> - 0.2.0-1quait2024
- new version 
- enable v4l2 support

* Tue Jul 18 2023 tex - 0.0.5-1pclos2023
- create for pipewire
